=======
audplot
=======

|tests| |coverage| |docs| |python-versions| |license|

**audplot** includes plotting functions targeted at
signal processing (e.g. spectral images)
and machine learning problems (e.g. confusion matrix).


.. badges images and links:
.. |tests| image:: https://github.com/audeering/audplot/workflows/Test/badge.svg
    :target: https://github.com/audeering/audplot/actions?query=workflow%3ATest
    :alt: Test status
.. |coverage| image:: https://codecov.io/gh/audeering/audplot/branch/master/graph/badge.svg?token=t5c5Ky64Ch
    :target: https://codecov.io/gh/audeering/audplot/
    :alt: code coverage
.. |docs| image:: https://img.shields.io/pypi/v/audplot?label=docs
    :target: https://audeering.github.io/audplot/
    :alt: audplot's documentation
.. |license| image:: https://img.shields.io/badge/license-MIT-green.svg
    :target: https://github.com/audeering/audplot/blob/master/LICENSE
    :alt: audplot's MIT license
.. |python-versions| image:: https://img.shields.io/pypi/pyversions/audplot.svg
    :target: https://pypi.org/project/audplot/
    :alt: audplot's supported Python versions
